tlslite.integration.xmlrpcserver.TLSXMLRPCServer

Package tlslite :: Package integration :: Module xmlrpcserver :: Class TLSXMLRPCServer |
[hide private]
[frames] | no frames]

# Class TLSXMLRPCServer

source code

        tlssocketservermixin.TLSSocketServerMixIn --+
                                                    |
                  SocketServer.BaseServer --+       |
                                            |       |
                       SocketServer.TCPServer --+   |
                                                |   |
    SimpleXMLRPCServer.SimpleXMLRPCDispatcher --+   |
                                                |   |
            SimpleXMLRPCServer.SimpleXMLRPCServer --+
                                                    |
                                                   TLSXMLRPCServer

Known Subclasses:
  - MultiPathTLSXMLRPCServer

Simple XML-RPC server using TLS

Instance Methods | [hide private]
__init__(self, addr, *args, **kwargs) Constructor. | source code
Inherited from `tlssocketservermixin.TLSSocketServerMixIn`: `finish_request`, `handshake` Inherited from `SocketServer.TCPServer`: `close_request`, `fileno`, `get_request`, `server_activate`, `server_bind`, `server_close`, `shutdown_request` Inherited from `SocketServer.BaseServer`: `handle_error`, `handle_request`, `handle_timeout`, `process_request`, `serve_forever`, `shutdown`, `verify_request` Inherited from `SocketServer.BaseServer` (private): `_handle_request_noblock` Inherited from `SimpleXMLRPCServer.SimpleXMLRPCDispatcher`: `register_function`, `register_instance`, `register_introspection_functions`, `register_multicall_functions`, `system_listMethods`, `system_methodHelp`, `system_methodSignature`, `system_multicall` Inherited from `SimpleXMLRPCServer.SimpleXMLRPCDispatcher` (private): `_dispatch`, `_marshaled_dispatch`

Class Variables | [hide private]
Inherited from `SimpleXMLRPCServer.SimpleXMLRPCServer`: `allow_reuse_address` Inherited from `SimpleXMLRPCServer.SimpleXMLRPCServer` (private): `_send_traceback_header` Inherited from `SocketServer.TCPServer`: `address_family`, `request_queue_size`, `socket_type` Inherited from `SocketServer.BaseServer`: `timeout`

Method Details | [hide private]

### __init__(self, addr, *args, **kwargs) (Constructor) | source code
Constructor. May be extended, do not override. Overrides: SimpleXMLRPCServer.SimpleXMLRPCDispatcher.__init__